@@ -14,9 +14,9 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU General Public License along
+ * with this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -310,8 +310,7 @@ eog_image_init (EogImage *img)
 	img->priv->file_is_changed = FALSE;
 	g_mutex_init (&img->priv->status_mutex);
 	img->priv->status = EOG_IMAGE_STATUS_UNKNOWN;
-        img->priv->metadata_status = EOG_IMAGE_METADATA_NOT_READ;
-	img->priv->is_monitored = FALSE;
+	img->priv->metadata_status = EOG_IMAGE_METADATA_NOT_READ;
 	img->priv->undo_stack = NULL;
 	img->priv->trans = NULL;
 	img->priv->trans_autorotate = NULL;
@@ -494,9 +493,9 @@ do_emit_size_prepared_signal (EogImage *img)
 static void
 eog_image_emit_size_prepared (EogImage *img)
 {
-	gdk_threads_add_idle_full (G_PRIORITY_DEFAULT_IDLE,
-				   (GSourceFunc) do_emit_size_prepared_signal,
-				   g_object_ref (img), g_object_unref);
+	g_idle_add_full (G_PRIORITY_DEFAULT_IDLE,
+			 (GSourceFunc) do_emit_size_prepared_signal,
+			 g_object_ref (img), g_object_unref);
 }
 
 static gboolean
